@@ -874,11 +874,14 @@ def initialize_config():
     # smartpip related files
     COMMON_PATH = os.path.join(AIRFLOW_HOME, 'common')
     ETL_SCRIPT_PATH = os.path.join(AIRFLOW_HOME, 'etl_script')
+    DAG_PATH = os.path.join(AIRFLOW_HOME, 'dags')
     FUNCTION_CONFIG = os.path.join(COMMON_PATH, 'functions.py')
     if not os.path.exists(COMMON_PATH):
         os.mkdir(COMMON_PATH)
     if not os.path.exists(ETL_SCRIPT_PATH):
         os.mkdir(ETL_SCRIPT_PATH)
+    if not os.path.exists(DAG_PATH):
+        os.mkdir(DAG_PATH)
     if not os.path.isfile(FUNCTION_CONFIG):
         shutil.copy(_default_config_file_path('default_functions.py'), WEBSERVER_CONFIG)
 
