@@ -40,6 +40,7 @@ DRIVES = {
     'refresh_smc': {'color': '#6675df'},
     'hdfsstarrocks': {'color': '#665998', 't': 'sql'},
     'kafkastarrocks': {'color': '#e8a6a6', 't': 'sql'},
+    'apistarrocks': {'color': '#eea6a6', 't': 'sql'},
     'routinestarrocks': {'color': '#b4a7d6'},
 }
 
@@ -166,6 +167,8 @@ def gen_airflow_dag(*args, **kwargs):
             etl_str = etl_str + execute_datax_format.format(project_name=project_name, filename=item[1], param=item[2])
         elif driver == 'kafkastarrocks':
             etl_str = etl_str + execute_kafkastarrocks_format.format(project_name=project_name, filename=item[1], param=item[2])
+        elif driver == 'apistarrocks':
+            etl_str = etl_str + execute_apistarrocks_format.format(project_name=project_name, filename=item[1], param=item[2])
         elif driver == 'routinestarrocks':
             etl_str = etl_str + execute_routinestarrocks_format.format(filename=item[1], label=item[2], flag=item[3])
         elif driver == 'dataxx':
